import { useCallback, useState, useRef } from "react";

export default function useTags(form) {
  const [tags, setTags] = useState({})
  const poisRef = useRef({})

  // const updatePoi2Form = pois => form.setFieldsValue('mapJson', Object.keys(pois).map((key) => ({ key, data: pois[key] })))

  // initPois 必须先于 initTags 执行
  // initPois, initTags 是在请求远程数据结束后执行
  const initPois = useCallback((raw) => {
    const newPois = !raw ? {} : raw.reduce((acc, poi) => {
      const { key, data } = poi
      return {
        ...acc,
        [key]: data || []
      }
    }, {})

    poisRef.current = newPois
  }, [])

  // 主要用于地图搜索周边结果
  const updatePois = useCallback((key, val) => {
    poisRef.current[key] = val

    // 先把 tags 中的 poi 去掉, 再更新
    const tagKey = `building${key}`
    const newTags = (tags[tagKey] || []).filter((tag) => !tag.id).concat(val)
    setTags({
      ...tags,
      [tagKey]: newTags,
    })

    // 更新form
    // updatePoi2Form(poisRef.current)
    // form.setFieldsValue({ [key]: newTags.map((tag) => tag.name).join(',') })
  }, [tags])

  // 主要用于单个 poi 删除
  const deletePoi = useCallback((key, val) => {
    if (!poisRef.current[key] || !poisRef.current[key].length) return;

    const newPois = poisRef.current[key].filter((poi) => poi.name !== val.name)
    poisRef.current[key] = newPois

    // 更新form
    // updatePoi2Form(poisRef.current)
  }, [])

  const updatePoisAndTags = useCallback((pois) => {
    poisRef.current = pois
    const keys = Object.keys(pois)
    
    const newTags = keys.reduce((acc, key) => {
      const tagKey = `building${key}`
      const arr = (tags[tagKey] || []).filter((tag) => !tag.id).concat(pois[key])
      return { ...acc, [tagKey]: arr }
    }, tags)

    setTags(newTags)
  }, [tags])

  const initTags = useCallback((key, raw) => {
    const tagArr = !raw ? [] : raw.split(',').filter(Boolean)

    if (!tagArr.length) return;

    const pois = poisRef.current[key] || []

    const newTags = tagArr.map((tag) => {
      const found = pois.filter((poi) => poi.name === tag)[0]

      return found || { name: tag }
    })

    setTags({
      ...tags,
      [key]: newTags,
    })
  }, [tags])

  const updateTags = useCallback((key, newTags = []) => {
    setTags({
      ...tags,
      [key]: newTags,
    })

    // form.setFieldsValue({ [key]: newTags.map((tag) => tag.name).join(',') })
  }, [tags])

  // 主要用户单个 tag 删除
  const deleteTag = useCallback((key, tag) => {
    if (!tags[key] || !tags[key].length) return;

    const leftTags = tags[key].filter((x) => x.name !== tag.name)

    setTags({
      ...tags,
      [key]: leftTags,
    })

    // form.setFieldsValue({ [key]: leftTags.map((tag) => tag.name).join(',') })
  })

  return [
    tags,
    initTags,
    updateTags,
    deletePoi,
    initPois,
    updatePois,
    deleteTag,
    updatePoisAndTags,
  ]
}
