import { useCallback, useEffect, useRef } from "react";

export default function usePoi(pois, tags, setTags) {
  const poiRef = useRef([])

  useEffect(() => {
    const len1 = !pois ? 0 : pois.length
    const len2 = poiRef.current.length

    // 空数据
    if (len1 === len2 && len1 === 0) {
      return
    }

    // 如果是 poiRef 更新导致了 pois 更新
    if (len1 > 0 && poiRef.current === pois) {
      return
    }

    // 如果是初始化
    poiRef.current = pois || []
  }, [pois])

  const updatePois = useCallback((pois) => {
    const newTags = tags.filter((tag) => !tag.id)
    setTags(newTags.concat(pois))
  }, [tags])

  const deletePoi = useCallback((poi) => {
    const newTags = tags.filter((tag) => tag.id !== poi.id)

    const newPois = !poiRef.current.length ? [] : poiRef.current.filter((p) => p.id !== poi.id)
    poiRef.current = newPois

    setTags(newTags)

    return newPois
  }, [tags])

  return [updatePois, deletePoi]
}
