import React, { useEffect, useRef, useState } from 'react'
import { Typography, Tag, Input, Icon } from 'antd'
import MapPois from './MapPois'
import { arrRemove, arrAdd } from './utils'

export default React.forwardRef((props, ref) => {
  const { tags = [], onPoiDelete, onDelete, onChange } = props

  const inputRef = useRef()
  const [inputValue, setInputValue] = useState()
  const [inputVisible, setInputVisible] = useState(false)

  const handleClose = (tag) => {
    if (tag.id && onPoiDelete) {
      onPoiDelete(tag)
    }

    if (onDelete) {
      onDelete(tag)
    }
  }

  const handleInputConfirm = () => {
    const exists = tags.filter((tag) => tag.name === inputValue)[0]
    if (!exists) {
      onChange(tags.concat({ name: inputValue }))
    }
    setInputVisible(false)
    setInputValue()
  }

  return (
    <div>
      {
        tags.map((tag) => (
          <Tag key={tag.name} closable onClose={() => handleClose(tag)}>
            <Typography.Text>{tag.name}</Typography.Text>
          </Tag>
        ))
      }
      {
        inputVisible ? (
          <Input
            ref={inputRef}
            type="text"
            size="small"
            style={{ width: 80, display: inputVisible ? 'inline-block' : 'none' }}
            value={inputValue}
            onChange={e => setInputValue(e.target.value)}
            onBlur={handleInputConfirm}
            onPressEnter={handleInputConfirm}
          />
        ) : (
          <Tag onClick={() => setInputVisible(true)} style={{ background: '#fff', borderStyle: 'dashed' }}>
            <Icon type="plus" /> 新建
          </Tag>
        )
      }
    </div>
  )
})
